@@ -3,9 +3,12 @@
  * @brief Header file for RendererBase class
  * @author Duzy Chan <code@duzy.info>
  *
- * @section LICENSE
+ * @ref License
+ */
+
+/* LICENSE
  *
- * Copyright (c) 2008-2014 OpenShot Studios, LLC
+ * Copyright (c) 2008-2019 OpenShot Studios, LLC
  * <http://www.openshotstudios.com/>. This file is part of
  * OpenShot Library (libopenshot), an open-source project dedicated to
  * delivering high quality video editing and animation solutions to the
@@ -28,7 +31,7 @@
 #ifndef OPENSHOT_RENDERER_BASE_H
 #define OPENSHOT_RENDERER_BASE_H
 
-#include "../include/Frame.h"
+#include "Frame.h"
 #include <stdlib.h> // for realloc
 #include <memory>
 
@@ -47,15 +50,15 @@ namespace openshot
     public:
 
 	/// Paint(render) a video Frame.
-	void paint(const std::shared_ptr<Frame> & frame);
+	void paint(const std::shared_ptr<openshot::Frame> & frame);
 
 	/// Allow manual override of the QWidget that is used to display
-	virtual void OverrideWidget(long long qwidget_address) = 0;
+	virtual void OverrideWidget(int64_t qwidget_address) = 0;
 
     protected:
 	RendererBase();
 	virtual ~RendererBase();
-	
+
 	virtual void render(std::shared_ptr<QImage> image) = 0;
     };
 
